@@ -2,12 +2,14 @@ import re
 import numpy as np
 import pandas as pd
 from pathlib import Path
+from pydantic import validate_arguments
 
 
 pattern = re.compile(r".+\[.+\]")
 pattern2 = re.compile(r"CMAST")
 
 
+@validate_arguments
 def kmm2(path: Path):
 
     skiprows = [
@@ -36,7 +38,7 @@ def kmm2(path: Path):
             "sweref99_tm_y",
             "contact_wire_material",
             "rail_model",
-            "sleeper_model",
+            "sliper_model",
             "between_stations",
             "5?",
             "6?",
